@@ -25,9 +25,9 @@
 #include <string.h>
 #include <stdlib.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <libgda/libgda.h>
 #include <libplanner/planner.h>
-#include <libplanner/mrp-intl.h>
 #include <libplanner/mrp-private.h>
 #include "mrp-storage-sql.h"
 #include "mrp-sql.h"
@@ -37,7 +37,7 @@
 #define REVISION "sql-storage-revision"
 
 /* Struct to keep calendar data before we can build the tree, create the
- * calendars and insert the in the project.
+ * calendars and insert them in the project.
  */
 typedef struct {
 	gint    id;
@@ -187,10 +187,11 @@ static GdaDataModel *
 sql_execute_query (GdaConnection *con, gchar *query)
 {
 	GdaCommand   *cmd;
-	GdaDataModel *res;
+	GdaDataModel *res = NULL;
+	GError       *error;
 
 	cmd = gda_command_new (query, GDA_COMMAND_TYPE_SQL, STOP_ON_ERR);
-	res = gda_connection_execute_single_command  (con, cmd, NULL);
+	res = gda_connection_execute_single_command  (con, cmd, NULL, &error);
 	gda_command_free (cmd);
 	return res;
 }
@@ -199,15 +200,18 @@ static const gchar *
 sql_get_last_error (GdaConnection *connection)
 {
 	GList       *list;
-	GdaError    *error;
+	GdaConnectionEvent   *error;
 	const gchar *error_txt;
 
-	list = (GList *) gda_connection_get_errors (connection);
+	g_return_val_if_fail (GDA_IS_CONNECTION (connection), 
+			      _("Can't connect to database server"));
 
-	error = (GdaError *) g_list_last (list)->data;
+	list = (GList *) gda_connection_get_events (connection);
+
+	error = (GdaConnectionEvent *) g_list_last (list)->data;
       
-	/* Poor user, she won't get localized messages */
-	error_txt = gda_error_get_description (error);
+	/* FIXME: Poor user, she won't get localized messages */
+	error_txt = gda_connection_event_get_description (error);
 
 	return error_txt;
 }
@@ -430,7 +434,7 @@ sql_read_project (SQLData *data, gint proj_id)
 	g_free (query);
 	
 	if (res == NULL) {
-		g_warning ("Couldn't get cursor for project %s.", 
+		g_warning ("DECLARE CURSOR command failed (project) %s.", 
 				sql_get_last_error (data->con));
 		goto out;
 	}
@@ -604,7 +608,7 @@ sql_read_property_specs (SQLData *data)
 	
 
 	if (res == NULL) {
-		g_warning ("DECLARE CURSOR command failed (propecty_specs) %s.",
+		g_warning ("DECLARE CURSOR command failed (property_type) %s.",
 				sql_get_last_error (data->con));
 		goto out;
 	}
@@ -612,7 +616,7 @@ sql_read_property_specs (SQLData *data)
 
 	res = sql_execute_query (data->con, "FETCH ALL in mycursor");
 	if (res == NULL) {
-		g_warning ("FETCH ALL failed for property_specs %s.", 
+		g_warning ("FETCH ALL failed for property_type %s.", 
 				sql_get_last_error (data->con));
 		goto out;
 	}
@@ -695,9 +699,10 @@ sql_read_property_specs (SQLData *data)
 						  TRUE /* FIXME: user_defined, should 
 							  be read from the file */);
 					
-			g_hash_table_insert (data->property_type_id_hash, GINT_TO_POINTER (property_type_id), property);
+			g_hash_table_insert (data->property_type_id_hash, 
+					     GINT_TO_POINTER (property_type_id), property);
 		} else {
-			/* Properties that are already added (e.g. cost). */
+			/* FIXME: Properties that are already added (e.g. cost). */
 			property = mrp_project_get_property (data->project, name, owner);
 			g_hash_table_insert (data->property_type_id_hash, GINT_TO_POINTER (property_type_id), property);
 		}
@@ -724,9 +729,9 @@ sql_read_property_specs (SQLData *data)
 
 static gboolean
 sql_set_property_value (SQLData     *data,
-			       MrpObject   *object,
-			       MrpProperty *property,
-			       const gchar *value)
+			MrpObject   *object,
+			MrpProperty *property,
+			const gchar *value)
 {
 	const gchar     *name;
 	MrpPropertyType  type;
@@ -2125,7 +2130,7 @@ sql_read_tasks (SQLData *data)
 
 gboolean
 mrp_sql_load_project (MrpStorageSQL *storage,
-		      const gchar   *server,
+		      const gchar   *host,
 		      const gchar   *port,
 		      const gchar   *database,
 		      const gchar   *login,
@@ -2145,7 +2150,8 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 
 	data = g_new0 (SQLData, 1);
 
-	data->project_id = -1;
+	data->project_id = -1; 
+	/* data->project_id = project_id; */
 	data->day_id_hash = g_hash_table_new (NULL, NULL);
 	data->calendar_id_hash = g_hash_table_new (NULL, NULL);
 	data->group_id_hash = g_hash_table_new (NULL, NULL);
@@ -2160,16 +2166,16 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 
 	data->root_task = mrp_task_new ();
 
-	db_txt = g_strdup_printf ("DATABASE=%s",database);
+	db_txt = g_strdup_printf ("HOST=%s;DATABASE=%s", host, database);
 	gda_config_save_data_source (dsn_name, 
                                      provider, 
                                      db_txt,
-                                     "planner project", login, password);
+                                     "planner project", login, password, FALSE);
 	g_free (db_txt);
 
 	client = gda_client_new ();
 
-	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0);
+	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, error);
 
 	if (!GDA_IS_CONNECTION (data->con)) {
 		g_warning (_("Connection to database '%s' failed.\n"), database);
@@ -2182,7 +2188,7 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 			sql_get_last_error (data->con));
 		goto out;
 	}
-	
+
 	res = sql_execute_query (data->con, "BEGIN");
 	if (res == NULL) {
 		g_warning (_("BEGIN command failed %s."),
@@ -2265,7 +2271,9 @@ mrp_sql_load_project (MrpStorageSQL *storage,
 		g_object_unref (res);
 	}
 	
-	g_object_unref (data->con);
+	if (data->con) {
+		g_object_unref (data->con);
+	}
 	return FALSE;
 
 	/* FIXME: free data */
@@ -3231,6 +3239,8 @@ sql_write_resources (SQLData *data)
 	const gchar     *is_worker;
 	gchar           *cal_id_string;
 	gchar           *group_id_string;
+
+	res = NULL;
 	
 	resources = mrp_project_get_resources (data->project);
 	for (l = resources; l; l = l->next) {
@@ -3315,7 +3325,7 @@ sql_write_resources (SQLData *data)
 static gboolean
 sql_write_tasks (SQLData *data)
 {
-	GdaDataModel    *res;
+	GdaDataModel    *res = NULL;
 	gchar           *query;	
 	GList           *tasks, *l;
 	gchar           *name, *note;	       
@@ -3567,9 +3577,9 @@ sql_write_tasks (SQLData *data)
 gboolean
 mrp_sql_save_project (MrpStorageSQL  *storage,
 		      gboolean        force,
-		      const gchar    *server,
+		      const gchar    *host,
 		      const gchar    *port,
-		      const gchar    *db,
+		      const gchar    *database,
 		      const gchar    *user,
 		      const gchar    *password,
 		      gint           *project_id,
@@ -3600,24 +3610,25 @@ mrp_sql_save_project (MrpStorageSQL  *storage,
 	
 	data->project = storage->project;
 
-	db_txt = g_strdup_printf ("DATABASE=%s",db);
+	db_txt = g_strdup_printf ("HOST=%s;DATABASE=%s", host, database);
 	gda_config_save_data_source (dsn_name, 
                                      provider,
 				     db_txt,
-                                     "planner project", user, password);
+                                     "planner project", user, password, FALSE);
 	g_free (db_txt);
 
 	client = gda_client_new ();
 
-	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0);
+	data->con = gda_client_open_connection (client, dsn_name, NULL, NULL, 0, error);
 	
-	data->revision = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (data->project), REVISION));
+	data->revision = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (data->project), 
+							     REVISION));
 
 	if (!GDA_IS_CONNECTION (data->con)) {
 		g_set_error (error,
 			     MRP_ERROR,
 			     MRP_ERROR_SAVE_WRITE_FAILED,
-			     _("Connection to database '%s' failed."), db);
+			     _("Connection to database '%s' failed."), database);
 		goto out;
 	}
 
